Package com.google.cloud.functions
Interface Context
public interface Context
An interface for event function context.
-
Method Summary
-
Method Details
-
eventId
Returns event ID.- Returns:
- event ID
-
timestamp
Returns event timestamp.- Returns:
- event timestamp
-
eventType
Returns event type.- Returns:
- event type
-
resource
Returns event resource.- Returns:
- event resource
-
attributes
Returns additional attributes from this event. For CloudEvents, the entries in this map will include the required attributes and may include optional attributes and extension attributes.The map returned by this method may be empty but is never null.
- Returns:
- additional attributes form this event.
-