Package com.google.cloud.functions
Interface HttpRequest.HttpPart
- All Superinterfaces:
HttpMessage
- Enclosing interface:
- HttpRequest
Represents one part inside a multipart (
multipart/form-data) HTTP request. Each such
part can have its own HTTP headers, which can be retrieved with the methods inherited from
HttpMessage.-
Method Summary
Modifier and TypeMethodDescriptionReturns the filename associated with this part, if any.Methods inherited from interface com.google.cloud.functions.HttpMessage
getCharacterEncoding, getContentLength, getContentType, getFirstHeader, getHeaders, getInputStream, getReader
-
Method Details
-
getFileName
Returns the filename associated with this part, if any.- Returns:
- the filename associated with this part, if any.
-